[Libreoffice-commits] core.git: svtools/source

Caolán McNamara caolanm at redhat.com
Fri Feb 21 02:12:50 PST 2014


 svtools/source/svhtml/htmlkywd.cxx |    5 ++---
 svtools/source/svhtml/parhtml.cxx  |   12 +++++-------
 2 files changed, 7 insertions(+), 10 deletions(-)

New commits:
commit 456b92609cdd0795e165ca4487419d1f329bb158
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Fri Feb 21 09:32:17 2014 +0000

    fdo#74584: complete revert various previous changes to upcase HTML tags
    
    f1f8b3bfdc3406ea79b662a2fda3d0c1cb87bb10 says it reverts
    
            commit 3c84fa61570113d1dfb2523ab88f268eeeb46c3c.
            commit 96a1f60aeb2a7954533da9b4aa4947efb7a65e70.
            commit 1f74a3ce201bad68f160584900285e2c087ab2c0.
            commit 3d481254a07fe82d11953f9825a2f8fc6eeabc0b.
    
    but only reverted 3d481254a07fe82d11953f9825a2f8fc6eeabc0b
    
    Change-Id: I0530bd0b176b1f1e9bbf8eee78376991c664a850

diff --git a/svtools/source/svhtml/htmlkywd.cxx b/svtools/source/svhtml/htmlkywd.cxx
index affbc86..c0b7915 100644
--- a/svtools/source/svhtml/htmlkywd.cxx
+++ b/svtools/source/svhtml/htmlkywd.cxx
@@ -189,7 +189,6 @@ static int SAL_CALL HTMLKeyCompare( const void *pFirst, const void *pSecond)
 
 int GetHTMLToken( const OUString& rName )
 {
-    OUString aNameUpper = rName.toAsciiUpperCase();
     if( !bSortKeyWords )
     {
         qsort( (void*) aHTMLTokenTab,
@@ -201,12 +200,12 @@ int GetHTMLToken( const OUString& rName )
 
     int nRet = 0;
 
-    if (!aNameUpper.compareTo(OOO_STRING_SVTOOLS_HTML_comment, 3))
+    if( !rName.compareTo( OOO_STRING_SVTOOLS_HTML_comment, 3  ) )
         return HTML_COMMENT;
 
     void* pFound;
     HTML_TokenEntry aSrch;
-    aSrch.pUToken = &aNameUpper;
+    aSrch.pUToken = &rName;
     aSrch.nToken = -1;
 
     pFound = bsearch( (sal_Char *) &aSrch,
diff --git a/svtools/source/svhtml/parhtml.cxx b/svtools/source/svhtml/parhtml.cxx
index a941a06..6517e5c 100644
--- a/svtools/source/svhtml/parhtml.cxx
+++ b/svtools/source/svhtml/parhtml.cxx
@@ -881,7 +881,7 @@ int HTMLParser::_GetNextRawToken()
                 }
 
                 OUString aTok( sTmpBuffer.toString() );
-                aTok = aTok.toAsciiUpperCase();
+                aTok = aTok.toAsciiLowerCase();
                 bool bDone = false;
                 if( bReadScript || !aEndToken.isEmpty() )
                 {
@@ -1126,7 +1126,7 @@ int HTMLParser::_GetNextToken()
 
                     // Search token in table:
                     sSaveToken = aToken;
-                    aToken = aToken.toAsciiUpperCase();
+                    aToken = aToken.toAsciiLowerCase();
                     if( 0 == (nRet = GetHTMLToken( aToken )) )
                         // Unknown control
                         nRet = HTML_UNKNOWNCONTROL_ON;
@@ -1462,10 +1462,8 @@ const HTMLOptions& HTMLParser::GetOptions( sal_uInt16 *pNoConvertToken )
 
             OUString sName( aToken.copy( nStt, nPos-nStt ) );
 
-            // PlugIns require original token name. Convert to upper case only for searching.
-            OUString sNameUpperCase( sName.toAsciiUpperCase() );
-
-            nToken = GetHTMLOption( sNameUpperCase ); // Name is ready
+            // PlugIns require original token name. Convert to lower case only for searching.
+            nToken = GetHTMLOption( sName.toAsciiLowerCase() ); // Name is ready
             DBG_ASSERTWARNING( nToken!=HTML_O_UNKNOWN,
                         "GetOption: unknown HTML option" );
             bool bStripCRLF = (nToken < HTML_OPTION_SCRIPT_START ||
@@ -1913,7 +1911,7 @@ bool HTMLParser::IsHTMLFormat( const sal_Char* pHeader,
         sCmp = pHeader;
     }
 
-    sCmp = sCmp.toAsciiUpperCase();
+    sCmp = sCmp.toAsciiLowerCase();
 
     // A HTML document must have a '<' in the first line
     sal_Int32 nStart = sCmp.indexOf('<');


More information about the Libreoffice-commits mailing list